==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/sl.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Zunanje shrambe",
    "Personal" : "Osebno",
    "System" : "Sistem",
    "Grant access" : "Odobri dostop",
    "Error configuring OAuth1" : "Napaka nastavljanja OAuth1",
    "Please provide a valid app key and secret." : "Vpisati je treba veljaven ključ programa in kodo PIN.",
    "Error configuring OAuth2" : "Napaka nastavljanja OAuth2",
    "Generate keys" : "Ustvari ključe",
    "Error generating key pair" : "Prišlo je do napake med ustvarjanjem para ključev",
    "All users. Type to select user or group." : "Vsi uporabniki. Skupino ali uporabnika je mogoče tudi izbrati.",
    "(group)" : "(skupina)",
    "Compatibility with Mac NFD encoding (slow)" : " Usklajenost s šifriranjem Mac NFD (počasno)",
    "Enable encryption" : "Omogoči šifriranje",
    "Enable previews" : "Omogoči predoglede",
    "Enable sharing" : "Omogoči souporabo",
    "Check for changes" : "Preveri za spremembe",
    "Never" : "Nikoli",
    "Once every direct access" : "Enkrat ob neposrednem dostopu",
    "Read only" : "Le za branje",
    "Delete" : "Izbriši",
    "Admin defined" : "Skrbnik je določen",
    "Are you sure you want to delete this external storage?" : "Ali ste prepričani, da želite izbrisati to  zunanjo shrambo?",
    "Delete storage?" : "Ali ste prepričani, da želite izbrisati shrambo?",
    "Saved" : "Shranjeno",
    "Saving..." : "Poteka shranjevanje ...",
    "Save" : "Shrani",
    "Empty response from the server" : "S strežnika je prejet odziv brez vsebine.",
    "Couldn't get the list of external mount points: {type}" : "Ni mogoče pridobiti seznama zunanjih priklopnih točk: {type}",
    "There was an error with message: " : "Prišlo je do napake s sporočilom:",
    "External mount error" : "Notranja napaka priklopa",
    "external-storage" : "zunanja-shramba",
    "Please enter the credentials for the {mount} mount" : "Vpišite poverila za priklopno točko {mount}",
    "Username" : "Uporabniško ime",
    "Password" : "Geslo",
    "Credentials saved" : "Poverila so shranjena",
    "Credentials saving failed" : "Shranjevanje poveril je spodletelo",
    "Credentials required" : "Zahtevana so poverila",
    "Invalid backend or authentication mechanism class" : "Neveljaven ozadnji program oziroma razred mehanizma overitve",
    "Invalid mount point" : "Neveljavna priklopna točka",
    "Objectstore forbidden" : "Shranjevanje predmeta je prepovedano",
    "Invalid storage backend \"%s\"" : "Neveljaven ozadnji program shrambe » %s «",
    "Not permitted to use backend \"%s\"" : "Uporaba ozadnjega programa \"%s\" ni dovoljena.",
    "Not permitted to use authentication mechanism \"%s\"" : "Uporaba načina overitve » %s « ni dovoljena.",
    "Unsatisfied backend parameters" : "Nezadovoljivi parametri ozadnjega programa",
    "Unsatisfied authentication mechanism parameters" : "Nezadovoljivi parametri mehanizma overitve",
    "Insufficient data: %s" : "Nepopolni podatki: %s",
    "%s" : "%s",
    "Access key" : "Ključ za dostop",
    "Secret key" : "Skrivni ključ",
    "Builtin" : "Vgrajeno",
    "None" : "Brez",
    "OAuth1" : "OAuth1",
    "App key" : "Programski ključ",
    "App secret" : "Skrivni programski ključ",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID odjemalca",
    "Client secret" : "Skrivni ključ odjemalca",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Ime uporabnika",
    "Identity endpoint URL" : "Naslov URL končne točke istovetnosti",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domena",
    "Rackspace" : "Rackspace",
    "API key" : "Ključ API",
    "Global credentials" : "Splošna poverila",
    "Log-in credentials, save in database" : "Prijavne poverilnice, shrani v bazo",
    "Username and password" : "Uporabniško ime in geslo",
    "Log-in credentials, save in session" : "Prijavna poverila, shrani v seji",
    "Global credentials, user entered" : "Uporabniško vpisana splošna poverila",
    "User entered, store in database" : "Uporabnik vnešen, vpis v bazo",
    "RSA public key" : "Javni ključ RSA",
    "Public key" : "Javni ključ",
    "RSA private key" : "Zasebni ključ RSA",
    "Private key" : "Zasebni ključ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Pomnilniško vedro",
    "Hostname" : "Ime gostitelja",
    "Port" : "Vrata",
    "Region" : "Območje",
    "Enable SSL" : "Omogoči SSL",
    "Enable Path Style" : "Omogoči slog poti",
    "WebDAV" : "WebDAV",
    "URL" : "Naslov URL",
    "Remote subfolder" : "Oddaljena podrejena mapa",
    "Secure https://" : "Varni način https://",
    "FTP" : "FTP",
    "Host" : "Gostitelj",
    "Secure ftps://" : "Varni način ftps://",
    "Local" : "Krajevno",
    "Location" : "Mesto",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Koren",
    "SFTP with secret key login" : "Prijava prek protokola SFTP z geslom",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Souporaba",
    "Show hidden files" : "Pokaži skrite datoteke",
    "Timeout" : "Časovni zamik",
    "SMB / CIFS using OC login" : "SMB / CIFS z uporabo prijave OC",
    "Username as share" : "Uporabniško ime za souporabo",
    "OpenStack Object Storage" : "Shramba predmeta OpenStack",
    "Service name" : "Ime storitve",
    "Request timeout (seconds)" : "Zahtevan časovni zamik (sekunde)",
    "External storage support" : "Podpora zunanjim hrambam",
    "Name" : "Ime",
    "Storage type" : "Vrsta shrambe",
    "Scope" : "Obseg",
    "Open documentation" : "Odpri dokumentacijo",
    "Folder name" : "Ime mape",
    "External storage" : "Zunanja shramba",
    "Authentication" : "Overitev",
    "Configuration" : "Nastavitve",
    "Available for" : "Na voljo za",
    "Add storage" : "Dodaj shrambo",
    "Advanced settings" : "Napredne nastavitve",
    "Allow users to mount external storage" : "Dovoli uporabnikom priklapljanje zunanje shrambe"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-18.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/sl.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Zunanje shrambe",
    "Personal" : "Osebno",
    "System" : "Sistem",
    "Grant access" : "Odobri dostop",
    "Error configuring OAuth1" : "Napaka nastavljanja OAuth1",
    "Please provide a valid app key and secret." : "Vpisati je treba veljaven ključ programa in kodo PIN.",
    "Error configuring OAuth2" : "Napaka nastavljanja OAuth2",
    "Generate keys" : "Ustvari ključe",
    "Error generating key pair" : "Prišlo je do napake med ustvarjanjem para ključev",
    "All users. Type to select user or group." : "Vsi uporabniki. Skupino ali uporabnika je mogoče tudi izbrati.",
    "(group)" : "(skupina)",
    "Compatibility with Mac NFD encoding (slow)" : " Usklajenost s šifriranjem Mac NFD (počasno)",
    "Enable encryption" : "Omogoči šifriranje",
    "Enable previews" : "Omogoči predoglede",
    "Enable sharing" : "Omogoči souporabo",
    "Check for changes" : "Preveri za spremembe",
    "Never" : "Nikoli",
    "Once every direct access" : "Enkrat ob neposrednem dostopu",
    "Read only" : "Le za branje",
    "Delete" : "Izbriši",
    "Admin defined" : "Skrbnik je določen",
    "Are you sure you want to delete this external storage?" : "Ali ste prepričani, da želite izbrisati to  zunanjo shrambo?",
    "Delete storage?" : "Ali ste prepričani, da želite izbrisati shrambo?",
    "Saved" : "Shranjeno",
    "Saving …" : "Poteka shranjevanje ...",
    "Save" : "Shrani",
    "Empty response from the server" : "S strežnika je prejet odziv brez vsebine.",
    "Couldn't get the information from the remote server: {code} {type}" : "Ni mogoče pridobiti podrobnosti z oddaljenega strežnika: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Ni mogoče pridobiti seznama zunanjih priklopnih točk: {type}",
    "There was an error with message: " : "Prišlo je do napake s sporočilom:",
    "External mount error" : "Notranja napaka priklopa",
    "external-storage" : "zunanja-shramba",
    "Please enter the credentials for the {mount} mount" : "Vpišite poverila za priklopno točko {mount}",
    "Username" : "Uporabniško ime",
    "Password" : "Geslo",
    "Credentials saved" : "Poverila so shranjena",
    "Credentials saving failed" : "Shranjevanje poveril je spodletelo",
    "Credentials required" : "Zahtevana so poverila",
    "Storage with ID \"%d\" not found" : "Shrambe z ID »%d« ni mogoče najti.",
    "Invalid backend or authentication mechanism class" : "Neveljaven ozadnji program oziroma razred mehanizma overitve",
    "Invalid mount point" : "Neveljavna priklopna točka",
    "Objectstore forbidden" : "Shranjevanje predmeta je prepovedano",
    "Invalid storage backend \"%s\"" : "Neveljaven ozadnji program shrambe » %s «",
    "Not permitted to use backend \"%s\"" : "Uporaba ozadnjega programa »%s« ni dovoljena.",
    "Not permitted to use authentication mechanism \"%s\"" : "Uporaba načina overitve » %s « ni dovoljena.",
    "Unsatisfied backend parameters" : "Nezadovoljivi parametri ozadnjega programa",
    "Unsatisfied authentication mechanism parameters" : "Nezadovoljivi parametri mehanizma overitve",
    "Insufficient data: %s" : "Nepopolni podatki: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Shrambe z ID »%d« ni mogoče uporabniško urediti.",
    "Access key" : "Ključ za dostop",
    "Secret key" : "Skrivni ključ",
    "Builtin" : "Vgrajeno",
    "None" : "Brez",
    "OAuth1" : "OAuth1",
    "App key" : "Programski ključ",
    "App secret" : "Skrivni programski ključ",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID odjemalca",
    "Client secret" : "Skrivni ključ odjemalca",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Ime uporabnika",
    "Identity endpoint URL" : "Naslov URL končne točke istovetnosti",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domena",
    "Rackspace" : "Rackspace",
    "API key" : "Ključ API",
    "Global credentials" : "Splošna poverila",
    "Log-in credentials, save in database" : "Prijavne poverilnice, shrani v bazo",
    "Username and password" : "Uporabniško ime in geslo",
    "Log-in credentials, save in session" : "Prijavna poverila, shrani v seji",
    "Global credentials, user entered" : "Uporabniško vpisana splošna poverila",
    "User entered, store in database" : "Uporabnik vnesen, vpis v bazo",
    "RSA public key" : "Javni ključ RSA",
    "Public key" : "Javni ključ",
    "RSA private key" : "Zasebni ključ RSA",
    "Private key" : "Zasebni ključ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Pomnilniško vedro",
    "Hostname" : "Ime gostitelja",
    "Port" : "Vrata",
    "Region" : "Območje",
    "Enable SSL" : "Omogoči SSL",
    "Enable Path Style" : "Omogoči slog poti",
    "Legacy (v2) authentication" : "Opuščena (v2) overitev",
    "WebDAV" : "WebDAV",
    "URL" : "Naslov URL",
    "Remote subfolder" : "Oddaljena podrejena mapa",
    "Secure https://" : "Varni način https://",
    "FTP" : "FTP",
    "Host" : "Gostitelj",
    "Secure ftps://" : "Varni način ftps://",
    "Local" : "Krajevno",
    "Location" : "Mesto",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Koren",
    "SFTP with secret key login" : "Prijava prek protokola SFTP z geslom",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Souporaba",
    "Show hidden files" : "Pokaži skrite datoteke",
    "Timeout" : "Časovni zamik",
    "SMB / CIFS using OC login" : "SMB / CIFS z uporabo prijave OC",
    "Username as share" : "Uporabniško ime za souporabo",
    "OpenStack Object Storage" : "Shramba predmeta OpenStack",
    "Service name" : "Ime storitve",
    "Request timeout (seconds)" : "Zahtevan časovni zamik (sekunde)",
    "External storage support" : "Podpora zunanji dhrambi",
    "Name" : "Ime",
    "Storage type" : "Vrsta shrambe",
    "Scope" : "Obseg",
    "Open documentation" : "Odpri dokumentacijo",
    "Folder name" : "Ime mape",
    "External storage" : "Zunanja shramba",
    "Authentication" : "Overitev",
    "Configuration" : "Nastavitve",
    "Available for" : "Na voljo za",
    "Click to recheck the configuration" : "Kliknite za ponovno preverjanje nastavitev",
    "Add storage" : "Dodaj shrambo",
    "Advanced settings" : "Napredne nastavitve",
    "Allow users to mount external storage" : "Dovoli uporabnikom priklapljanje zunanje shrambe",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Splošna poverila je mogoče uporabiti za overitev z več zunanjimi shrambami, ki uporabljajo enaka poverila.",
    "Saving..." : "Poteka shranjevanje ..."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
